spacepy.toolbox.update — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.update

`spacepy.toolbox.` `update`(all=True, QDomni=False, omni=False, omni2=False, leapsecs=False, PSDdata=False)

  Download and update local database for omni, leapsecs etc

  Parameters: | all : boolean (optional) if True, update OMNI2, Qin-Denton and leapsecs omni : boolean (optional) if True. update only omni (Qin-Denton) omni2 : boolean (optional) if True, update only original OMNI2 QDomni : boolean (optional) if True, update OMNI2 and Qin-Denton leapsecs : boolean (optional) if True, update only leapseconds
  Returns: | out : string data directory where things are saved

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.update(omni=True)

### Navigation

- index
- modules |
- modules |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »